pub enum ContentSource {
Inline {
content: FileContent,
},
File {
path: PathBuf,
},
Url {
url: String,
},
}Expand description
Source of file content - inline or external reference.
Represents where file content comes from, allowing flexibility in how archives store their data. Content can be embedded directly, referenced from filesystem, fetched from URLs, or retrieved via custom user-defined mechanisms.
Variants
Inline: Content embedded directly in the archive (default behavior)File: Reference to a file in the local filesystemUrl: Reference to a remote resource (HTTP/HTTPS)
Examples
use genfile_core::{ ContentSource, FileContent };
use std::path::PathBuf;
// Inline content
let inline = ContentSource::Inline
{
content: FileContent::Text( "Hello {{name}}".into() ),
};
// File reference
let file_ref = ContentSource::File
{
path: PathBuf::from( "/templates/main.hbs" ),
};
// Remote URL
let remote = ContentSource::Url
{
url: "https://example.com/template.hbs".into(),
};Variants
Inline
Content embedded directly in archive
Fields

content: FileContentThe actual file content
File
Reference to file in local filesystem
Url
Reference to remote resource
Implementations
Sourceimpl ContentSource
impl ContentSource
Sourcepub fn as_inline(&self) -> Option<&FileContent>
pub fn as_inline(&self) -> Option<&FileContent>
Get inline content if available
Sourcepub fn as_file_path(&self) -> Option<&Path>
pub fn as_file_path(&self) -> Option<&Path>
Get file path if this is a file reference